@@ -16,6 +16,7 @@ import org.gnu.gdk.Point;
 import org.gnu.gdk.Screen;
 import org.gnu.gdk.WindowHints;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 
 /**
@@ -29,7 +30,7 @@ public class Window extends Bin {
 	/**
 	 * Construct a new Window object.
 	 * 
-	 * @param type The type of window to create
+	 * @param windowType The type of window to create
 	 */
 	public Window(WindowType windowType) {
 		super(Window.gtk_window_new(windowType.getValue()));
@@ -41,7 +42,7 @@ public class Window extends Bin {
 	 * 
 	 * @param handle The handle that represents a pointer to a native resource.
 	 */
-	public Window(int handle) {
+	public Window(Handle handle) {
 	    super(handle);
 	}
 	
@@ -160,10 +161,10 @@ public class Window extends Bin {
 	 * @return The Widget that has focus.
 	 */
 	public Widget getFocusWidget() {
-		int hndl = gtk_window_get_focus(getHandle());
-		if (0 == hndl)
+	    Handle hndl = gtk_window_get_focus(getHandle());
+		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle( hndl );
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -329,7 +330,6 @@ public class Window extends Bin {
 	
 	/**
 	 * Returns whether this window should appear in the task bar.
-	 * @return
 	 */
 	public boolean getSkipTaskbarHint() {
 		return gtk_window_get_skip_taskbar_hint(getHandle());
@@ -345,7 +345,6 @@ public class Window extends Bin {
 
 	/**
 	 * Returns whether the window should appear in the pager.
-	 * @return
 	 */
 	public boolean getSkipPagerHint() {
 		return gtk_window_get_skip_pager_hint(getHandle());
@@ -364,8 +363,8 @@ public class Window extends Bin {
 	}
 
 	public Screen getScreen() {
-		int hndl = gtk_window_get_screen(getHandle());
-		GObject obj = retrieveGObject(hndl);
+	    Handle hndl = gtk_window_get_screen(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Screen)obj;
 		return new Screen(hndl);
@@ -380,11 +379,11 @@ public class Window extends Bin {
 	}
 
 	public boolean setIconFromFile(String filename) {
-		return gtk_window_set_icon_from_file(getHandle(), filename, new int[] {});
+		return gtk_window_set_icon_from_file(getHandle(), filename);
 	}
 	
 	public static boolean setDefaultIconFromFile(String filename) {
-		return gtk_window_set_default_icon_from_file(filename, new int[] {});
+		return gtk_window_set_default_icon_from_file(filename);
 	}
 	
 	public static void setDefaultIcon(Pixbuf icon) {
@@ -414,7 +413,7 @@ public class Window extends Bin {
 	public static void setDefaultIconList(Pixbuf[] icons) {
 		if (null == icons)
 			return;
-		int[] hndls = new int[icons.length];
+		Handle[] hndls = new Handle[icons.length];
 		for (int i = 0; i < icons.length; i++) {
 			hndls[i] = icons[i].getHandle();
 		}
@@ -422,7 +421,7 @@ public class Window extends Bin {
 	}
 	
 	public static Pixbuf[] getDefaultIconList() {
-		int[] hndls = gtk_window_get_default_icon_list();
+	    Handle[] hndls = gtk_window_get_default_icon_list();
 		Pixbuf[] pbs = new Pixbuf[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
 			pbs[i] = new Pixbuf(hndls[i]);
@@ -431,7 +430,7 @@ public class Window extends Bin {
 	}
 	
 	public static Window[] listToplevelWindows() {
-		int[] hndls = gtk_window_list_toplevels();
+	    Handle[] hndls = gtk_window_list_toplevels();
 		Window[] wins = new Window[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
 			wins[i] = new Window(hndls[i]);
@@ -446,90 +445,85 @@ public class Window extends Bin {
 		return new Type(gtk_window_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
 	native static final protected int gtk_window_get_type();
-	native static final protected int gtk_window_new(int type);
-	native static final protected void gtk_window_set_title(int window, String title);
-	native static final protected String gtk_window_get_title(int window);
-	native static final protected void gtk_window_set_wmclass(int window, String  wmclassName, String wmclassClass);
-	native static final protected void gtk_window_set_role(int window, String role);
-	native static final protected String gtk_window_get_role(int window);
-	native static final protected void gtk_window_add_accel_group(int window, int accelGroup);
-	native static final protected void gtk_window_remove_accel_group(int window, int accelGroup);
-	native static final protected void gtk_window_set_position(int window, int position);
-	native static final protected int gtk_window_activate_focus(int window);
-	native static final protected void gtk_window_set_focus(int window, int focus);
-	native static final protected int gtk_window_get_focus(int window);
-	native static final protected void gtk_window_set_default(int window, int defaultWidget);
-	native static final protected boolean gtk_window_activate_default(int window);
-	native static final protected void gtk_window_set_transient_for(int window, int parent);
-	native static final protected int gtk_window_get_transient_for(int window);
-	native static final protected void gtk_window_set_type_hint(int window, int hint);
-	native static final protected int gtk_window_get_type_hint(int window);
-	native static final protected void gtk_window_set_skip_taskbar_hint(int window, boolean skip);
-	native static final protected boolean gtk_window_get_skip_taskbar_hint(int window);
-	native static final protected void gtk_window_set_skip_pager_hint(int window, boolean skip);
-	native static final protected boolean gtk_window_get_skip_pager_hint(int window);
-	native static final protected void gtk_window_set_accept_focus(int window, boolean setting);
-	native static final protected boolean gtk_window_get_accept_focus(int window);
-	native static final protected void gtk_window_set_destroy_with_parent(int window, boolean setting);
-	native static final protected boolean gtk_window_get_destroy_with_parent(int window);
-	native static final protected void gtk_window_set_resizable(int window, boolean resizable);
-	native static final protected boolean gtk_window_get_resizable(int window);
-	native static final protected void gtk_window_set_gravity(int window, int gravity);
-	native static final protected int gtk_window_get_gravity(int window);
-	native static final protected void gtk_window_set_geometry_hints(int window, int geometryWidget, int geometry, int geomMask);
-	native static final protected void gtk_window_set_screen(int window, int screen);
-	native static final protected int gtk_window_get_screen(int window);
-	native static final protected boolean gtk_window_is_active(int window);
-	native static final protected boolean gtk_window_has_toplevel_focus(int window);
-	native static final protected void gtk_window_set_has_frame(int window, boolean setting);
-	native static final protected boolean gtk_window_get_has_frame(int window);
-	native static final protected void gtk_window_set_frame_dimensions(int window, int left, int top, int right, int bottom);
-	native static final protected void gtk_window_get_frame_dimensions(int window, int[] left, int[] top, int[] right, int[] bottom);
-	native static final protected void gtk_window_set_decorated(int window, boolean setting);
-	native static final protected boolean gtk_window_get_decorated(int window);
-	native static final protected void gtk_window_set_icon_list(int window, int list);
-	native static final protected int gtk_window_get_icon_list(int window);
-	native static final protected void gtk_window_set_icon(int window, int icon);
-	native static final protected int gtk_window_get_icon(int window);
-	native static final protected boolean gtk_window_set_icon_from_file(int window, String filename, int[] error);
-	native static final protected void gtk_window_set_default_icon_list(int[] list);
-	native static final protected int[] gtk_window_get_default_icon_list();
-	native static final protected boolean gtk_window_set_default_icon_from_file(String filename, int[] error);
-	native static final protected void gtk_window_set_default_icon(int icon);
+	native static final protected Handle gtk_window_new(int type);
+	native static final protected void gtk_window_set_title(Handle window, String title);
+	native static final protected String gtk_window_get_title(Handle window);
+	native static final protected void gtk_window_set_wmclass(Handle window, String  wmclassName, String wmclassClass);
+	native static final protected void gtk_window_set_role(Handle window, String role);
+	native static final protected String gtk_window_get_role(Handle window);
+	native static final protected void gtk_window_add_accel_group(Handle window, Handle accelGroup);
+	native static final protected void gtk_window_remove_accel_group(Handle window, Handle accelGroup);
+	native static final protected void gtk_window_set_position(Handle window, int position);
+	native static final protected int gtk_window_activate_focus(Handle window);
+	native static final protected void gtk_window_set_focus(Handle window, Handle focus);
+	native static final protected Handle gtk_window_get_focus(Handle window);
+	native static final protected void gtk_window_set_default(Handle window, Handle defaultWidget);
+	native static final protected boolean gtk_window_activate_default(Handle window);
+	native static final protected void gtk_window_set_transient_for(Handle window, Handle parent);
+	native static final protected Handle gtk_window_get_transient_for(Handle window);
+	native static final protected void gtk_window_set_type_hint(Handle window, int hint);
+	native static final protected int gtk_window_get_type_hint(Handle window);
+	native static final protected void gtk_window_set_destroy_with_parent(Handle window, boolean setting);
+	native static final protected boolean gtk_window_get_destroy_with_parent(Handle window);
+	native static final protected void gtk_window_set_resizable(Handle window, boolean resizable);
+	native static final protected boolean gtk_window_get_resizable(Handle window);
+	native static final protected void gtk_window_set_gravity(Handle window, int gravity);
+	native static final protected int gtk_window_get_gravity(Handle window);
+	native static final protected void gtk_window_set_geometry_hints(Handle window, Handle geometryWidget, Handle geometry, int geomMask);
+	native static final protected void gtk_window_set_has_frame(Handle window, boolean setting);
+	native static final protected boolean gtk_window_get_has_frame(Handle window);
+	native static final protected void gtk_window_set_frame_dimensions(Handle window, int left, int top, int right, int bottom);
+	native static final protected void gtk_window_get_frame_dimensions(Handle window, int[] left, int[] top, int[] right, int[] bottom);
+	native static final protected void gtk_window_set_decorated(Handle window, boolean setting);
+	native static final protected boolean gtk_window_get_decorated(Handle window);
+	native static final protected void gtk_window_set_icon_list(Handle window, Handle list);
+	native static final protected Handle gtk_window_get_icon_list(Handle window);
+	native static final protected void gtk_window_set_icon(Handle window, Handle icon);
+	native static final protected Handle gtk_window_get_icon(Handle window);
+	native static final protected void gtk_window_set_default_icon_list(Handle[] list);
+	native static final protected Handle[] gtk_window_get_default_icon_list();
+	native static final protected void gtk_window_set_modal(Handle window, boolean modal);
+	native static final protected boolean gtk_window_get_modal(Handle window);
+	native static final protected Handle[] gtk_window_list_toplevels();
+	native static final protected void gtk_window_add_mnemonic(Handle window, int keyval, Handle target);
+	native static final protected void gtk_window_remove_mnemonic(Handle window, int keyval, Handle target);
+	native static final protected boolean gtk_window_mnemonic_activate(Handle window, int keyval, int modifier);
+	native static final protected void gtk_window_set_mnemonic_modifier(Handle window, int modifier);
+	native static final protected int gtk_window_get_mnemonic_modifier(Handle window);
+	native static final protected void gtk_window_present(Handle window);
+	native static final protected void gtk_window_iconify(Handle window);
+	native static final protected void gtk_window_deiconify(Handle window);
+	native static final protected void gtk_window_stick(Handle window);
+	native static final protected void gtk_window_unstick(Handle window);
+	native static final protected void gtk_window_maximize(Handle window);
+	native static final protected void gtk_window_unmaximize(Handle window);
+	native static final protected void gtk_window_begin_resize_drag(Handle window, int edge, int button, int rootX, int rootY, int timestamp);
+	native static final protected void gtk_window_begin_move_drag(Handle window, int button, int rootX, int rootY, int timestamp);
+	native static final protected void gtk_window_set_default_size(Handle window, int width, int height);
+	native static final protected void gtk_window_get_default_size(Handle window, int[] width, int[] height);
+	native static final protected void gtk_window_resize(Handle window, int width, int height);
+	native static final protected void gtk_window_get_size(Handle window, int[] width, int[] height);
+	native static final protected void gtk_window_move(Handle window, int x, int y);
+	native static final protected void gtk_window_get_position(Handle window, int[] rootX, int[] rootY);
+	native static final protected boolean gtk_window_parse_geometry(Handle window, String geometry);
+	native static final protected void gtk_window_set_skip_taskbar_hint(Handle window, boolean skip);
+	native static final protected boolean gtk_window_get_skip_taskbar_hint(Handle window);
+	native static final protected void gtk_window_set_skip_pager_hint(Handle window, boolean skip);
+	native static final protected boolean gtk_window_get_skip_pager_hint(Handle window);
+	native static final protected void gtk_window_set_accept_focus(Handle window, boolean setting);
+	native static final protected boolean gtk_window_get_accept_focus(Handle window);
+	native static final protected void gtk_window_set_screen(Handle window, Handle screen);
+	native static final protected Handle gtk_window_get_screen(Handle window);
+	native static final protected boolean gtk_window_is_active(Handle window);
+	native static final protected boolean gtk_window_has_toplevel_focus(Handle window);
+	native static final protected boolean gtk_window_set_icon_from_file(Handle window, String filename);
+	native static final protected boolean gtk_window_set_default_icon_from_file(String filename);
+	native static final protected void gtk_window_set_default_icon(Handle icon);
 	native static final protected void gtk_window_set_auto_startup_notification(boolean setting);
-	native static final protected void gtk_window_set_modal(int window, boolean modal);
-	native static final protected boolean gtk_window_get_modal(int window);
-	native static final protected int[] gtk_window_list_toplevels();
-	native static final protected void gtk_window_add_mnemonic(int window, int keyval, int target);
-	native static final protected void gtk_window_remove_mnemonic(int window, int keyval, int target);
-	native static final protected boolean gtk_window_mnemonic_activate(int window, int keyval, int modifier);
-	native static final protected void gtk_window_set_mnemonic_modifier(int window, int modifier);
-	native static final protected int gtk_window_get_mnemonic_modifier(int window);
-	native static final protected void gtk_window_present(int window);
-	native static final protected void gtk_window_iconify(int window);
-	native static final protected void gtk_window_deiconify(int window);
-	native static final protected void gtk_window_stick(int window);
-	native static final protected void gtk_window_unstick(int window);
-	native static final protected void gtk_window_maximize(int window);
-	native static final protected void gtk_window_unmaximize(int window);
-	native static final protected void gtk_window_fullscreen(int window);
-	native static final protected void gtk_window_unfullscreen(int window);
-	native static final protected void gtk_window_set_keep_above(int window, boolean setting);
-	native static final protected void gtk_window_set_keep_below(int window, boolean setting);
-	native static final protected void gtk_window_begin_resize_drag(int window, int edge, int button, int rootX, int rootY, int timestamp);
-	native static final protected void gtk_window_begin_move_drag(int window, int button, int rootX, int rootY, int timestamp);
-	native static final protected void gtk_window_set_default_size(int window, int width, int height);
-	native static final protected void gtk_window_get_default_size(int window, int[] width, int[] height);
-	native static final protected void gtk_window_resize(int window, int width, int height);
-	native static final protected void gtk_window_get_size(int window, int[] width, int[] height);
-	native static final protected void gtk_window_move(int window, int x, int y);
-	native static final protected void gtk_window_get_position(int window, int[] rootX, int[] rootY);
-	native static final protected boolean gtk_window_parse_geometry(int window, String geometry);
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
+	native static final protected void gtk_window_fullscreen(Handle window);
+	native static final protected void gtk_window_unfullscreen(Handle window);
+	native static final protected void gtk_window_set_keep_above(Handle window, boolean setting);
+	native static final protected void gtk_window_set_keep_below(Handle window, boolean setting);
+
 }
